

-- STEP 1: generate the list of users to migrate


create table users_to_merge (
    userIdToRemove int
,	userIdToModify int
);

-- This select statement will remove all USER_NAMEs where there is a corresponding USER_NAME_old1 user.
-- Comment it out if you'd prefer to manually choose users.
insert into users_to_merge (userIdToRemove, userIdToModify)
select
	new_user.cru_user_id,
  old_user.cru_user_id
from cru_user old_user
inner join cru_user new_user
	on new_user.cru_user_name = substr(old_user.cru_user_name, 1, length(old_user.cru_user_name) - 5)
where old_user.cru_user_name like '%_old1';

-- This template will let you run the merge function on a specific pair of users.
-- Uncomment it if you'd prefer to individually choose pairs of users to revert.

-- insert into users_to_merge (userIdToRemove, userIdToModify)
-- select
-- 	new_user.cru_user_id,
--   old_user.cru_user_id
-- from cru_user old_user
-- cross join cru_user new_user
-- where old_user.cru_user_name = 'OLD_USER_NAME - to be modified'
-- and new_user.cru_user_name = 'NEW_USER_NAME - to be removed';


-- this query will display a list of which users are going to be merged into which usernames
-- Run this after running 
-- SELECT (select cru_user_name from cru_user where  cru_user_id = userIdToRemove) username_to_remove,
-- (select cru_user_name from cru_user where  cru_user_id = userIdToModify) username_to_modify
-- FROM users_to_merge



-- STEP 2: run this to do the migration

update cru_changeset_comment targetTable
set cru_user_id =
  (select userIdToModify from users_to_merge where userIdToRemove = targetTable.cru_user_id)
where cru_user_id in (select userIdToRemove from users_to_merge);

--
  -- merge in the new data
update cru_proj_allowed_reviewer  toRemove
set cru_user_id =
  (select userIdToModify from users_to_merge where userIdToRemove = toRemove.cru_user_id)
where not exists(
	select 1 from cru_proj_allowed_reviewer toModify
    where toModify.cru_project_id = toRemove.cru_project_id
    and toModify.cru_user_id in (select userIdToModify from users_to_merge
      where users_to_merge.userIdToRemove = toRemove.cru_user_id)
) and cru_user_id in (select userIdToRemove from users_to_merge);
  -- delete the duplicates 
delete 
from cru_proj_allowed_reviewer
where cru_user_id in (select userIdToRemove from users_to_merge);


--

update cru_proj_default_reviewer  toRemove
set cru_user_id =
  (select userIdToModify from users_to_merge where userIdToRemove = toRemove.cru_user_id)
where not exists(
	select 1 from cru_proj_default_reviewer toModify
    where toModify.cru_project_id = toRemove.cru_project_id
    and toModify.cru_user_id in (select userIdToModify from users_to_merge
      where users_to_merge.userIdToRemove = toRemove.cru_user_id)
) and cru_user_id in (select userIdToRemove from users_to_merge);

delete 
from cru_proj_default_reviewer
where cru_user_id in (select userIdToRemove from users_to_merge);

--

update cru_notification targetTable
set cru_actioner =
  (select userIdToModify from users_to_merge where userIdToRemove = targetTable.cru_actioner)
where cru_actioner in (select userIdToRemove from users_to_merge);

--

update cru_review_participant toRemove
set cru_user = (select userIdToModify from users_to_merge where userIdToRemove = toRemove.cru_user)
where ( not exists (
    select 1 from cru_review_participant toModify
    where toModify.cru_review_id = toRemove.cru_review_id
    and toModify.cru_user in (select userIdToModify from users_to_merge
      where users_to_merge.userIdToRemove = toRemove.cru_user)
)) and cru_user in (select userIdToRemove from users_to_merge);


delete cru_file_read_status
where cru_participant in (select cru_participant_id
	from cru_review_participant partic
    where cru_user in (select userIdToRemove from users_to_merge));

delete cru_review_participant
where cru_user in (select userIdToRemove from users_to_merge);

--

update cru_review targetTable
set cru_creator =
    (select userIdToModify from users_to_merge where userIdToRemove = targetTable.cru_creator)
where cru_creator in (select userIdToRemove from users_to_merge);

--

update cru_upload_item targetTable
set cru_user =
    (select userIdToModify from users_to_merge where userIdToRemove = targetTable.cru_user)
where cru_user in (select userIdToRemove from users_to_merge);

--

update cru_recipient targetTable
set cru_user =
    (select userIdToModify from users_to_merge where userIdToRemove = targetTable.cru_user)
where cru_user in (select userIdToRemove from users_to_merge);

--

update cru_project targetTable
set cru_default_moderator =
    (select userIdToModify from users_to_merge where userIdToRemove = targetTable.cru_default_moderator)
where cru_default_moderator in (select userIdToRemove from users_to_merge);

--

update cru_comment_read_status toRemove
set cru_user = (select userIdToModify from users_to_merge where userIdToRemove = toRemove.cru_user)
where ( not exists (
    select 1 from cru_comment_read_status toModify
    where toModify.cru_comment = toRemove.cru_comment
    and toModify.cru_user in (select userIdToModify from users_to_merge
      where users_to_merge.userIdToRemove = toRemove.cru_user)
))  and cru_user in (select userIdToRemove from users_to_merge);

delete cru_comment_read_status
where cru_user in (select userIdToRemove from users_to_merge);

--

update cru_user_app_link toRemove
set cru_user = (select userIdToModify from users_to_merge where userIdToRemove = toRemove.cru_user)
where ( not exists (
    select 1 from cru_user_app_link toModify
    where toModify.cru_app_link_id = toRemove.cru_app_link_id
    and toModify.cru_user in (select userIdToModify from users_to_merge
      where users_to_merge.userIdToRemove = toRemove.cru_user)
))  and cru_user in (select userIdToRemove from users_to_merge);

delete cru_user_app_link
where cru_user in (select userIdToRemove from users_to_merge);

--

update cru_comment targetTable
set cru_user_id = (select userIdToModify from users_to_merge where userIdToRemove = targetTable.cru_user_id)
where cru_user_id in (select userIdToRemove from users_to_merge);

--

update cru_state_change targetTable
set cru_user = (select userIdToModify from users_to_merge where userIdToRemove = targetTable.cru_user)
where cru_user in (select userIdToRemove from users_to_merge);

--

update cru_logitem targetTable
set cru_user_id = (select userIdToModify from users_to_merge where userIdToRemove = targetTable.cru_user_id)
where cru_user_id in (select userIdToRemove from users_to_merge);
	
update cru_logitem targetTable
set cru_entity_id = (select userIdToModify from users_to_merge where userIdToRemove = targetTable.cru_entity_id)
where cru_action in ('REVIEW_REVIEWER_ADDED', 'REVIEW_REVIEWER_ADDED_MID_REVIEW')
    and cru_entity_id in (select userIdToRemove from users_to_merge);

--

delete from cru_user_profile up
where cru_user_id in (select userIdToRemove from users_to_merge);

--

delete from cru_user
where cru_user_id in (select userIdToRemove from users_to_merge);




-- STEP 3: when everything looks good, feel free to drop the temporary table.  You can optionally use this table for the next steps
drop table users_to_merge;
